# HydroMT Dashboard
A dashboard user interface for building spatial geoscientific models with a focus on water systems models.

### Local development
Develop pip install this repository.
Use the following command line argument inside your environment to run the dashboard in debug mode: 
```
hydromt_dash_dev
```
To run the main version of the dashboard use:

```
hydromt_dash
```